/*******************************************************
 *
 * $Id$
 *
 * This file has been placed in the public domain.
 *
 *******************************************************/


#ifndef DEMOACTIONENGINE_H
#define DEMOACTIONENGINE_H

#include <PalmOS.h>

#include "Customization.h"

#include "ActionEngine.h"
#include "Canvas.h"
#include "HardKeyManager.h"
#include "SpriteEngine.h"
#include "SoundEngine.h"


/**
 * DemoActionEngine demonstrates the implementation of a
 * customized ActionEngine. 
 */
class DemoActionEngine : public ActionEngine
{
	public:

	DemoActionEngine() : ActionEngine()
	{
		sprite1 = new Sprite(2000, 2001, 42,75, true, Sprite::optBUFFER);
		sprite2 = new Sprite(2000, 2001, 42,75, true, Sprite::optBUFFER);

		spriteGroup = new SpriteGroup(2);
		spriteGroup->addSprite(*sprite1);
		spriteGroup->addSprite(*sprite2);
	}


	~DemoActionEngine()
	{
	}

	
	void restart()
	{
		state.periodCounter = state.lastMoved = 0;
		state.xCoord = 20;
		state.yCoord = 20;
		state.targetXCoord = -1;

		SoundEngine::playSong(0);
	}


	void nextPeriod()
	{
		state.periodCounter++;

		// Move to the location of the last pen tap.
		if (state.targetXCoord != -1)
		{
			state.lastMoved = state.periodCounter;

			state.xCoord = state.targetXCoord;
			state.yCoord = state.targetYCoord;

			state.targetXCoord = -1;
		}


		// Evaluate the currently pressed keys
		UInt32 keyState = HardKeyManager::getCurrentState();

		if (keyState & (keyBitHard1 | keyBitHard2 | keyBitHard3 | keyBitHard4 | keyBitPageDown | keyBitPageUp))
		{
			state.lastMoved = state.periodCounter;
				
			if (keyState & keyBitHard1)
				state.xCoord -= 5;
			else if (keyState & keyBitHard2)
				state.xCoord += 5;

			if (keyState & keyBitPageDown)
				state.yCoord += 5;
			else if (keyState & keyBitPageUp)
				state.yCoord -= 5;


			if (keyState & keyBitHard3)
			{
				SoundEngine::playFx(0);
				sprite1->setVisibility(!(sprite1->isVisible()));
			}

			if (keyState & keyBitHard4)
				sprite2->setVisibility(!(sprite2->isVisible()));
		}

				
		// Walk around if the user hasn't moved us for a while...
		if ((state.periodCounter - state.lastMoved) > 200)
			state.xCoord += 3;


		// Wrap around at screen edge
		state.xCoord %= 200;
		state.yCoord %= 200;
		
		sprite1->move(state.xCoord, state.yCoord);
		sprite2->move(100 - state.xCoord, state.yCoord + 10);
	}


	WinLockInitType getWinLockMode() const
	{
		return winLockErase;   // We always want a clear background.
	}


	void draw(RectangleType *bounds) const
	{
		// Paint sprites
		spriteGroup->draw(bounds);
	}


	void receiveEvent(const EventType* evtPtr)
	{
/*		if ((evtPtr->eType == penDownEvent) || (evtPtr->eType == penMoveEvent))
		{
			state.targetXCoord = evtPtr->screenX;
			state.targetYCoord = evtPtr->screenY;
		}  */
	}


// ================================== Save & Restore =============================================================

	void* getRestoreStateBuffer()
	{
		return &state;
	}
	
	void releaseRestoreStateBuffer(void* /* stateBuffer */) const
	{
		// The state buffer is static. Do nothing.
	}
	
	void* getSaveStateBuffer()
	{
		return &state;
	}
	
	void releaseSaveStateBuffer(void* /* stateBuffer */) const
	{
		// The state buffer is static. Do nothing.
	}
	
	Int16 getStateBufferSize() const
	{
		return sizeof(state);
	}

	void restoreState(void *stateBuffer)
	{
		ErrFatalDisplayIf(stateBuffer != &state, "State buffer mismatch!");

		sprite1->move(state.xCoord, state.yCoord);
		sprite2->move(100 - state.xCoord, state.yCoord + 10);
	}


	private:	

	struct
	{
		UInt32 periodCounter;
		UInt32 lastMoved;
	
		Coord xCoord;
		Coord yCoord;

		Coord targetXCoord;
		Coord targetYCoord;
	} state;


	Sprite *sprite1;
	Sprite *sprite2;
	SpriteGroup *spriteGroup;
};


#endif
